# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from dinari_api_sdk import Dinari, AsyncDinari
from dinari_api_sdk.types.api.v2.market_data.stocks import (
    SplitListResponse,
    SplitRetrieveResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestSplits:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    def test_method_retrieve(self, client: Dinari) -> None:
        split = client.api.v2.market_data.stocks.splits.retrieve(
            stock_id="stock_id",
        )
        assert_matches_type(SplitRetrieveResponse, split, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_retrieve_with_all_params(self, client: Dinari) -> None:
        split = client.api.v2.market_data.stocks.splits.retrieve(
            stock_id="stock_id",
            page=1,
            page_size=1,
        )
        assert_matches_type(SplitRetrieveResponse, split, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_retrieve(self, client: Dinari) -> None:
        response = client.api.v2.market_data.stocks.splits.with_raw_response.retrieve(
            stock_id="stock_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        split = response.parse()
        assert_matches_type(SplitRetrieveResponse, split, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_retrieve(self, client: Dinari) -> None:
        with client.api.v2.market_data.stocks.splits.with_streaming_response.retrieve(
            stock_id="stock_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            split = response.parse()
            assert_matches_type(SplitRetrieveResponse, split, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_path_params_retrieve(self, client: Dinari) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `stock_id` but received ''"):
            client.api.v2.market_data.stocks.splits.with_raw_response.retrieve(
                stock_id="",
            )

    @pytest.mark.skip()
    @parametrize
    def test_method_list(self, client: Dinari) -> None:
        split = client.api.v2.market_data.stocks.splits.list()
        assert_matches_type(SplitListResponse, split, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_list_with_all_params(self, client: Dinari) -> None:
        split = client.api.v2.market_data.stocks.splits.list(
            page=1,
            page_size=1,
        )
        assert_matches_type(SplitListResponse, split, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_list(self, client: Dinari) -> None:
        response = client.api.v2.market_data.stocks.splits.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        split = response.parse()
        assert_matches_type(SplitListResponse, split, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_list(self, client: Dinari) -> None:
        with client.api.v2.market_data.stocks.splits.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            split = response.parse()
            assert_matches_type(SplitListResponse, split, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncSplits:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_retrieve(self, async_client: AsyncDinari) -> None:
        split = await async_client.api.v2.market_data.stocks.splits.retrieve(
            stock_id="stock_id",
        )
        assert_matches_type(SplitRetrieveResponse, split, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_retrieve_with_all_params(self, async_client: AsyncDinari) -> None:
        split = await async_client.api.v2.market_data.stocks.splits.retrieve(
            stock_id="stock_id",
            page=1,
            page_size=1,
        )
        assert_matches_type(SplitRetrieveResponse, split, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncDinari) -> None:
        response = await async_client.api.v2.market_data.stocks.splits.with_raw_response.retrieve(
            stock_id="stock_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        split = await response.parse()
        assert_matches_type(SplitRetrieveResponse, split, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncDinari) -> None:
        async with async_client.api.v2.market_data.stocks.splits.with_streaming_response.retrieve(
            stock_id="stock_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            split = await response.parse()
            assert_matches_type(SplitRetrieveResponse, split, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncDinari) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `stock_id` but received ''"):
            await async_client.api.v2.market_data.stocks.splits.with_raw_response.retrieve(
                stock_id="",
            )

    @pytest.mark.skip()
    @parametrize
    async def test_method_list(self, async_client: AsyncDinari) -> None:
        split = await async_client.api.v2.market_data.stocks.splits.list()
        assert_matches_type(SplitListResponse, split, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncDinari) -> None:
        split = await async_client.api.v2.market_data.stocks.splits.list(
            page=1,
            page_size=1,
        )
        assert_matches_type(SplitListResponse, split, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncDinari) -> None:
        response = await async_client.api.v2.market_data.stocks.splits.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        split = await response.parse()
        assert_matches_type(SplitListResponse, split, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncDinari) -> None:
        async with async_client.api.v2.market_data.stocks.splits.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            split = await response.parse()
            assert_matches_type(SplitListResponse, split, path=["response"])

        assert cast(Any, response.is_closed) is True
